| countmaskr_data | R Documentation |
A synthetic dataset of 1500 subjects with demographic information ascertaining at least one category from the demographics has counts less than 11.
data(countmaskr_data)
countmaskr_dataA data frame with 1500 rows and 6 columns:
Subject id
Age in years as integer
Administrative sex
Race
Ethnicity
Age as categorical variable
...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.