countmaskr dataset
countmaskr_data.RdA synthetic dataset of 1500 subjects with demographic information ascertaining at least one category from the demographics has counts less than 11.
Usage
data(countmaskr_data)
countmaskr_data.RdA synthetic dataset of 1500 subjects with demographic information ascertaining at least one category from the demographics has counts less than 11.
data(countmaskr_data)